# pyzeversolar

This library was created to communicate with ZeverSolar inverters within Home Assistant.
It is based on the pysma component written by @kellerza and the pysaj component written by @fredericvl